@@ -255,9 +255,9 @@ float Fstat_num_denum(const float *Y, const int* L,const int n, const float na,f
 		   k is the number of groups,
 		   N is the total number of validate objects*/
   k=*(int*)extra;
-  meani=(float *)Calloc(k,float);
-  ssi=(float *)Calloc(k,float);
-  ni=(int *)Calloc(k,int);
+  meani=(float *)R_Calloc(k,float);
+  ssi=(float *)R_Calloc(k,float);
+  ni=(int *)R_Calloc(k,int);
   for(i=0;i<k;i++){
     meani[i]=0;/*intialize to be zero*/
     ssi[i]=0;
@@ -297,9 +297,9 @@ float Fstat_num_denum(const float *Y, const int* L,const int n, const float na,f
   /*summarize the num and denum*/
   *num=bss/(k-1.0);
   *denum=wss/(N-k-0.0);
-  Free(meani);
-  Free(ni);
-  Free(ssi);
+  R_Free(meani);
+  R_Free(ni);
+  R_Free(ssi);
   return 1;
 } 
 /*compute the Block F-stat for k samples, where L[i] is the labelling of object i,
@@ -328,8 +328,8 @@ float Block_Fstat_num_denum(const float *Y, const int* L,const int n, const floa
     fprintf(stderr,"The design is not balanced as B(%d)xm(%d)!=n(%d)\n",B,m,n);
     return NA_FLOAT;
   }
-  meani=(float *)Calloc(B,float);
-  meanj=(float *)Calloc(m,float);
+  meani=(float *)R_Calloc(B,float);
+  meanj=(float *)R_Calloc(m,float);
   for(i=0;i<B;i++){
     meani[i]=0;/*intialize to be zero*/
     for(j=0;j<m;j++){
@@ -369,8 +369,8 @@ float Block_Fstat_num_denum(const float *Y, const int* L,const int n, const floa
   /*summarize the num and denum*/
   *num=bss/(m-1.0);
   *denum=wss/((m-1.0)*(B-1.0));
-  Free(meani);
-  Free(meanj);
+  R_Free(meani);
+  R_Free(meanj);
   return 1;
 } 
 void int2bin(int r,int*V,int n)
@@ -501,7 +501,7 @@ void label2sample(int n, int k, int* nk,int*L,int *permun)
   int *s;/*s is for starting*/
 
   /*initialize the beginning*/
-  s=(int*)Calloc(k,int);
+  s=(int*)R_Calloc(k,int);
   s[0]=0;
   for(l=1;l<k;l++){
     s[l]=s[l-1]+nk[l-1];
@@ -511,17 +511,17 @@ void label2sample(int n, int k, int* nk,int*L,int *permun)
     permun[s[l]]=j;
     s[l]++;
   }
-  Free(s);
+  R_Free(s);
 }
   
 int next_label(int n, int k, int* nk, int*L)
 {
   int *permun,ret;
-  permun=(int*)Calloc(n,int);
+  permun=(int*)R_Calloc(n,int);
   label2sample(n,k,nk,L,permun);
   ret=next_mult_permu(permun,n,k,nk);
   sample2label(n,k,nk,permun,L);
-  Free(permun);
+  R_Free(permun);
   return ret;
 }
 
@@ -538,7 +538,7 @@ int next_two_permu(int* V, int n, int k)
   int* A=V;
   int* B=V+k;
   int* tempV,*cpyV;
-  tempV=(int*)Calloc(n,int);
+  tempV=(int*)R_Calloc(n,int);
 
   i=k-1;
   while(i>=0&& A[i]>maxb){
@@ -554,7 +554,7 @@ int next_two_permu(int* V, int n, int k)
     /*using the tempV to swap the array A and array B*/
     memcpy(V,tempV,sizeof(int)*n);
     /*coppying back to V*/
-    Free(tempV);
+    R_Free(tempV);
     return 0;
   }
   /*else to find the next permutation*/
@@ -574,7 +574,7 @@ int next_two_permu(int* V, int n, int k)
   /*copy the ((n-k)-(j+1)) elements from array 
     B[j+1],...B[n-k-1],..,A[i+1],..A[k-1]*/
   /*construct the array B[j+1],...B[n-k-1],A[i+1],..A[k-1]*/
-  cpyV=(int*)Calloc(n,int);
+  cpyV=(int*)R_Calloc(n,int);
   memcpy(cpyV,B+j+1,sizeof(int)*((n-k)-(j+1)));
   if(k>(i+1))
     memcpy(cpyV+(n-k)-(j+1),A+i+1,sizeof(int)*(k-(i+1)));
@@ -584,8 +584,8 @@ int next_two_permu(int* V, int n, int k)
     memcpy(tempV+k+j+2,cpyV+(k-i),sizeof(int)*((n-k)-(j+2)));
   /*copy back to V*/
   memcpy(V,tempV,sizeof(int)*n);
-  Free(cpyV);
-  Free(tempV);
+  R_Free(cpyV);
+  R_Free(tempV);
   return 1;
 }
 
@@ -642,14 +642,14 @@ int next_permu(int*V,int n) /* n has to be at least 2*/
     if(V[j]>old) break;
     j--;
   }
-  cpyV=(int*)Calloc(n,int);
+  cpyV=(int*)R_Calloc(n,int);
   memcpy(cpyV,V,sizeof(int)*n);
   V[i]=cpyV[j];
   cpyV[j]=old;
   for(l=i+1;l<n;l++){
     V[l]=cpyV[n+i-l];
   }
-  Free(cpyV);
+  R_Free(cpyV);
   return 1;
 }
 
@@ -700,18 +700,22 @@ void read_infile(char *filename,GENE_DATA *pdata) {
   if (NULL == fh)
       Rf_error("failed to open file '%s'", filename);
   /*read the labelling first*/
-  fscanf(fh, "%s", pdata->name);
-  for (j=0; j<pdata->ncol; j++)
-    fscanf(fh, "%d", pdata->L+j);
-
+  int res=fscanf(fh, "%s", pdata->name);
+  if(res != 1) Rf_error("error reading file '%s'", filename);
+  for (j=0; j<pdata->ncol; j++){
+    res=fscanf(fh, "%d", pdata->L+j);
+    if(res != 1) Rf_error("error reading file '%s'", filename);
+  }
 /*read the mxn matrix of the gene values data*/
   for (i=0; i<pdata->nrow; i++) {
     /*read gene id and the first gene values*/
-    fscanf(fh, "%s", pdata->id[i]);
+    res=fscanf(fh, "%s", pdata->id[i]);
+    if(res != 1) Rf_error("error reading file '%s'", filename);
     /*read the rest of it*/
     for (j=0; j<pdata->ncol; j++) {
       /*deal with the double data*/
-      fscanf(fh, "%lg",&ftemp);
+      res=fscanf(fh, "%lg",&ftemp);
+      if(res != 1) Rf_error("error reading file '%s'", filename);
       pdata->d[i][j]=ftemp;
     }
   }
